@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2006-2008 Advanced Micro Devices, Inc. All Rights Reserved.
+# Copyright (c) 2006-2009 Advanced Micro Devices, Inc. All Rights Reserved.
 # This software is subject to the Apache v2.0 License.
 #
 
@@ -38,6 +38,11 @@ class fwBuildRoot:
         self.dctFwVars['toolset']        = ARGUMENTS.get('toolset',   '---')
         self.dctFwVars['wincrt']         = ARGUMENTS.get('wincrt',    '---')
         self.dctFwVars['thread']         = ARGUMENTS.get('thread',    'pthread')
+        self.dctFwVars['CCFLAGS']         = ARGUMENTS.get('CCFLAGS',    '')
+
+        self.dctFwVars['REF_CCFLAGS']         = ARGUMENTS.get('REF_CCFLAGS',    '')
+        self.dctFwVars['SSE2_CCFLAGS']         = ARGUMENTS.get('SSE2_CCFLAGS',    '')
+        self.dctFwVars['F10H_CCFLAGS']         = ARGUMENTS.get('F10H_CCFLAGS',    '')
 
 
         if self.dctFwVars['thread'] == 'systemboost':
@@ -84,7 +89,7 @@ class fwBuildRoot:
             self.dctFwVars['debuginfo'] = 'off'
 
         curEnviron = createEnviron()
-        self.oEnv = Environment( toolpath=buildtoolspath, tools=buildtools, ENV=curEnviron, FWVARS=self.dctFwVars )
+        self.oEnv = Environment( CCFLAGS = self.dctFwVars['CCFLAGS'] , toolpath=buildtoolspath, tools=buildtools, ENV=curEnviron, FWVARS=self.dctFwVars )
 
 		# fixup paths back to what they were before scons messed them up [BUGBUG: SCons issue, this is the workaround]
         if ((sys.platform=='win32') and (self.dctFwVars['bitness']!='32')):
