@@ -1,8 +1,8 @@
 /*
-Copyright (c) 2006-2008 Advanced Micro Devices, Inc. All Rights Reserved.
+Copyright (c) 2006-2009 Advanced Micro Devices, Inc. All Rights Reserved.
 This software is subject to the Apache v2.0 License.
 */
- 
+
 // this extern "C" is needed to activate documentation - kludge
 extern "C" {
 
@@ -88,8 +88,8 @@ fwStsLengthErr - Invalid string length.
 
 /*#Documentation
 
-<VersionNumber>1.2.0</VersionNumber>
-<VersionDate>Aug, 2008</VersionDate>
+<VersionNumber>1.3.0</VersionNumber>
+<VersionDate>Dec, 2008</VersionDate>
 <FrameMaster></FrameMaster>
 <HeaderMaster></HeaderMaster>
 <NavBar></NavBar>
@@ -107,7 +107,7 @@ fwStsLengthErr - Invalid string length.
 <FrontLink>aa_007_tcd</FrontLink>
 </FrontHeading>
 
-<Paragraph>Copyright &#169; 2007-2008 The Framewave Group. All Rights Reserved.</Paragraph>
+<Paragraph>Copyright &#169; 2007-2009 The Framewave Group. All Rights Reserved.</Paragraph>
 <Paragraph>Framewave is a trademark of The Framewave Group.</Paragraph>
 <Paragraph>AMD is a registered trademark of Advanced Micro Devices, Inc.</Paragraph>
 <Paragraph>Microsoft and Windows are registered trademarks of Microsoft Corporation.</Paragraph>
@@ -129,12 +129,12 @@ fwStsLengthErr - Invalid string length.
 <ChangeEntry>
 <ChangeDate>02/2008</ChangeDate>
 <ChangeVersion>1.0.0</ChangeVersion>
-<ChangeDescription>Initial release.</ChangeDescription> 
+<ChangeDescription>Initial release.</ChangeDescription>
 </ChangeEntry>
 <ChangeEntry>
 <ChangeDate>03/2008</ChangeDate>
 <ChangeVersion>1.0.1</ChangeVersion>
-<ChangeDescription>Removed Video Library.</ChangeDescription> 
+<ChangeDescription>Removed Video Library.</ChangeDescription>
 </ChangeEntry>
 <ChangeEntry>
 <ChangeDate>05/2008</ChangeDate>
@@ -152,37 +152,37 @@ fwStsLengthErr - Invalid string length.
 
 <ChangeItem>Color to gray scale conversion functions
 
-<ChangeSubItem>fwiColorToGray_8u_C3C1R</ChangeSubItem>   
-<ChangeSubItem>fwiColorToGray_16u_C3C1R</ChangeSubItem>  
-<ChangeSubItem>fwiColorToGray_16s_C3C1R</ChangeSubItem>  
-<ChangeSubItem>fwiColorToGray_32f_C3C1R</ChangeSubItem>  
-<ChangeSubItem>fwiColorToGray_8u_AC4C1R</ChangeSubItem>  
-<ChangeSubItem>fwiColorToGray_16u_AC4C1R</ChangeSubItem> 
-<ChangeSubItem>fwiColorToGray_16s_AC4C1R</ChangeSubItem> 
-<ChangeSubItem>fwiColorToGray_32f_AC4C1R</ChangeSubItem> 
-<ChangeSubItem>fwiRGBToGray_8u_C3C1R</ChangeSubItem>     
-<ChangeSubItem>fwiRGBToGray_16u_C3C1R</ChangeSubItem>    
-<ChangeSubItem>fwiRGBToGray_16s_C3C1R</ChangeSubItem>    
-<ChangeSubItem>fwiRGBToGray_32f_C3C1R</ChangeSubItem>    
-<ChangeSubItem>fwiRGBToGray_8u_AC4C1R</ChangeSubItem>    
-<ChangeSubItem>fwiRGBToGray_16u_AC4C1R</ChangeSubItem>   
-<ChangeSubItem>fwiRGBToGray_16s_AC4C1R</ChangeSubItem>   
-<ChangeSubItem>fwiRGBToGray_32f_AC4C1R</ChangeSubItem>  
+<ChangeSubItem>fwiColorToGray_8u_C3C1R</ChangeSubItem>
+<ChangeSubItem>fwiColorToGray_16u_C3C1R</ChangeSubItem>
+<ChangeSubItem>fwiColorToGray_16s_C3C1R</ChangeSubItem>
+<ChangeSubItem>fwiColorToGray_32f_C3C1R</ChangeSubItem>
+<ChangeSubItem>fwiColorToGray_8u_AC4C1R</ChangeSubItem>
+<ChangeSubItem>fwiColorToGray_16u_AC4C1R</ChangeSubItem>
+<ChangeSubItem>fwiColorToGray_16s_AC4C1R</ChangeSubItem>
+<ChangeSubItem>fwiColorToGray_32f_AC4C1R</ChangeSubItem>
+<ChangeSubItem>fwiRGBToGray_8u_C3C1R</ChangeSubItem>
+<ChangeSubItem>fwiRGBToGray_16u_C3C1R</ChangeSubItem>
+<ChangeSubItem>fwiRGBToGray_16s_C3C1R</ChangeSubItem>
+<ChangeSubItem>fwiRGBToGray_32f_C3C1R</ChangeSubItem>
+<ChangeSubItem>fwiRGBToGray_8u_AC4C1R</ChangeSubItem>
+<ChangeSubItem>fwiRGBToGray_16u_AC4C1R</ChangeSubItem>
+<ChangeSubItem>fwiRGBToGray_16s_AC4C1R</ChangeSubItem>
+<ChangeSubItem>fwiRGBToGray_32f_AC4C1R</ChangeSubItem>
 
 </ChangeItem>
 
 <ChangeItem>Color format conversion functions
 
-<ChangeSubItem>fwiYCbCr422ToYCbCr420_8u_C2P3R</ChangeSubItem>  
-<ChangeSubItem>fwiYCbCr422ToYCbCr420_8u_P3R</ChangeSubItem>  
-<ChangeSubItem>fwiYCbCr422_8u_P3C2R</ChangeSubItem>  
+<ChangeSubItem>fwiYCbCr422ToYCbCr420_8u_C2P3R</ChangeSubItem>
+<ChangeSubItem>fwiYCbCr422ToYCbCr420_8u_P3R</ChangeSubItem>
+<ChangeSubItem>fwiYCbCr422_8u_P3C2R</ChangeSubItem>
 
 </ChangeItem>
 
 <ChangeItem>64s support for Add and Sub functions
 
 <ChangeSubItem>fwsAdd_64s</ChangeSubItem>
-<ChangeSubItem>fwsSub_64s</ChangeSubItem> 
+<ChangeSubItem>fwsSub_64s</ChangeSubItem>
 
 </ChangeItem>
 
@@ -195,13 +195,13 @@ fwStsLengthErr - Invalid string length.
 
 <ChangeItem>Min and Max functions
 
-<ChangeSubItem>fwsMin_8s</ChangeSubItem> 
+<ChangeSubItem>fwsMin_8s</ChangeSubItem>
 <ChangeSubItem>fwsMin_64u</ChangeSubItem>
-<ChangeSubItem>fwsMax_8s</ChangeSubItem> 
+<ChangeSubItem>fwsMax_8s</ChangeSubItem>
 <ChangeSubItem>fwsMax_64u</ChangeSubItem>
 
 </ChangeItem>
-	
+
 </ChangeDescription>
 
 <ChangeDescription>Optimized functions:
@@ -211,15 +211,15 @@ fwStsLengthErr - Invalid string length.
 <ChangeSubItem>fwiRGBToYCbCr422LS_MCU_8u16s_C3P3R</ChangeSubItem>
 <ChangeSubItem>fwiRGBToYCbCr444LS_MCU_8u16s_C3P3R</ChangeSubItem>
 <ChangeSubItem>fwiRGBToYCbCr411LS_MCU_8u16s_C3P3R</ChangeSubItem>
-<ChangeSubItem>fwiBGRToYCbCr411LS_MCU_8u16s_C3P3R</ChangeSubItem>	
-<ChangeSubItem>fwiBGRToYCbCr444LS_MCU_8u16s_C3P3R</ChangeSubItem>  
+<ChangeSubItem>fwiBGRToYCbCr411LS_MCU_8u16s_C3P3R</ChangeSubItem>
+<ChangeSubItem>fwiBGRToYCbCr444LS_MCU_8u16s_C3P3R</ChangeSubItem>
 
 </ChangeItem>
 
 <ChangeItem>Normal color conversion functions
 
-<ChangeSubItem>fwiRGBToHSV_8u_C3R</ChangeSubItem>  
-<ChangeSubItem>fwiYCbCr422_8u_P3C2R</ChangeSubItem>  
+<ChangeSubItem>fwiRGBToHSV_8u_C3R</ChangeSubItem>
+<ChangeSubItem>fwiYCbCr422_8u_P3C2R</ChangeSubItem>
 <ChangeSubItem>fwiRGBToYCbCr420_8u_C3P3R</ChangeSubItem>
 
 </ChangeItem>
@@ -236,19 +236,19 @@ fwStsLengthErr - Invalid string length.
 <ChangeSubItem>fwiResizeSqrPixel_8u_C1R</ChangeSubItem>
 <ChangeSubItem>fwiResizeSqrPixel_8u_C3R</ChangeSubItem>
 <ChangeSubItem>fwiResizeSqrPixel_8u_C4R</ChangeSubItem>
-<ChangeSubItem>fwiResizeSqrPixel_8u_AC4R</ChangeSubItem> 
+<ChangeSubItem>fwiResizeSqrPixel_8u_AC4R</ChangeSubItem>
 
 </ChangeItem>
 
 <ChangeItem>Rotate functions
 
-<ChangeSubItem>fwiRotate_8u_C1R</ChangeSubItem>  
-<ChangeSubItem>fwiRotate_8u_C3R</ChangeSubItem>  
-<ChangeSubItem>fwiRotate_8u_C4R</ChangeSubItem>  
-<ChangeSubItem>fwiRotate_8u_AC4R</ChangeSubItem> 
-<ChangeSubItem>fwiRotate_16u_C1R</ChangeSubItem> 
-<ChangeSubItem>fwiRotate_16u_C3R</ChangeSubItem> 
-<ChangeSubItem>fwiRotate_16u_C4R</ChangeSubItem> 
+<ChangeSubItem>fwiRotate_8u_C1R</ChangeSubItem>
+<ChangeSubItem>fwiRotate_8u_C3R</ChangeSubItem>
+<ChangeSubItem>fwiRotate_8u_C4R</ChangeSubItem>
+<ChangeSubItem>fwiRotate_8u_AC4R</ChangeSubItem>
+<ChangeSubItem>fwiRotate_16u_C1R</ChangeSubItem>
+<ChangeSubItem>fwiRotate_16u_C3R</ChangeSubItem>
+<ChangeSubItem>fwiRotate_16u_C4R</ChangeSubItem>
 <ChangeSubItem>fwiRotate_16u_AC4R</ChangeSubItem>
 <ChangeSubItem>fwiRotate_32f_C1R</ChangeSubItem>
 <ChangeSubItem>fwiRotate_32f_C3R</ChangeSubItem>
@@ -347,6 +347,61 @@ fwStsLengthErr - Invalid string length.
 
 </ChangeEntry>
 
+<ChangeEntry>
+<ChangeDate>12/2008</ChangeDate>
+<ChangeVersion>1.3.0</ChangeVersion>
+<ChangeDescription>New functions:
+
+<ChangeItem>Convert functions
+
+<ChangeSubItem>fwsConvert_16u32s</ChangeSubItem>
+<ChangeSubItem>fwsConvert_8u16s</ChangeSubItem>
+<ChangeSubItem>fwsConvert_32u16s</ChangeSubItem>
+<ChangeSubItem>fwsConvert_32u32f</ChangeSubItem>
+<ChangeSubItem>fwsConvert_32u64f</ChangeSubItem>
+<ChangeSubItem>fwsConvert_16u32f_Sfs</ChangeSubItem>
+
+
+<ChangeSubItem>fwiConvert_32f8u_C1R</ChangeSubItem>
+<ChangeSubItem>fwiConvert_32f8u_C3R</ChangeSubItem>
+<ChangeSubItem>fwiConvert_32f8u_C4R</ChangeSubItem>
+<ChangeSubItem>fwiConvert_32f8u_AC4R</ChangeSubItem>
+<ChangeSubItem>fwiConvert_32f8s_C1R</ChangeSubItem>
+<ChangeSubItem>fwiConvert_32f8s_C3R</ChangeSubItem>
+<ChangeSubItem>fwiConvert_32f8s_C4R</ChangeSubItem>
+<ChangeSubItem>fwiConvert_32f8s_AC4R</ChangeSubItem>
+<ChangeSubItem>fwiConvert_32f16s_C1R</ChangeSubItem>
+<ChangeSubItem>fwiConvert_32f16s_C3R</ChangeSubItem>
+<ChangeSubItem>fwiConvert_32f16s_C4R</ChangeSubItem>
+<ChangeSubItem>fwiConvert_32f16s_AC4R </ChangeSubItem>
+<ChangeSubItem>fwiConvert_32f16u_C1R</ChangeSubItem>
+<ChangeSubItem>fwiConvert_32f16u_C3R</ChangeSubItem>
+<ChangeSubItem>fwiConvert_32f16u_C4R</ChangeSubItem>
+<ChangeSubItem>fwiConvert_32f16u_AC4R</ChangeSubItem>
+</ChangeItem>
+
+<ChangeItem>Memory management functions
+
+<ChangeSubItem>fwsMalloc_8u</ChangeSubItem>
+<ChangeSubItem>fwsMalloc_16u</ChangeSubItem>
+<ChangeSubItem>fwsMalloc_32u</ChangeSubItem>
+<ChangeSubItem>fwsMalloc_8s</ChangeSubItem>
+<ChangeSubItem>fwsMalloc_16s</ChangeSubItem>
+<ChangeSubItem>fwsMalloc_32s</ChangeSubItem>
+<ChangeSubItem>fwsMalloc_64s</ChangeSubItem>
+<ChangeSubItem>fwsMalloc_32f</ChangeSubItem>
+<ChangeSubItem>fwsMalloc_64f</ChangeSubItem>
+<ChangeSubItem>fwsMalloc_16sc</ChangeSubItem>
+<ChangeSubItem>fwsMalloc_32sc</ChangeSubItem>
+<ChangeSubItem>fwsMalloc_64sc</ChangeSubItem>
+<ChangeSubItem>fwsMalloc_32fc</ChangeSubItem>
+<ChangeSubItem>fwsMalloc_64fc</ChangeSubItem>
+
+</ChangeItem>
+
+</ChangeDescription>
+</ChangeEntry>
+
 </ChangeHistory>
 
 </FrontSection>
@@ -360,22 +415,22 @@ fwStsLengthErr - Invalid string length.
 <H1Link>aa_005_intro</H1Link>
 </Heading1>
 
-<Paragraph> Framewave (FW) is a collection of libraries that contain highly-optimized 
- functions for use in a variety of programming domains. All implementations 
+<Paragraph> Framewave (FW) is a collection of libraries that contain highly-optimized
+ functions for use in a variety of programming domains. All implementations
  of the libraries provide C and C++ programmers ANSI C style interfaces.</Paragraph>
 
 <Paragraph>Framewave consists of the following libraries:</Paragraph>
 
 <IntroLinks></IntroLinks>
 
-<Paragraph>Framewave functions are geared to yield maximum performance on the x86 and the AMD64 hardware architectures. 
-Current implementations exploit multicore architecture and single instruction multiple data (SIMD) instructions. 
-Specifically, streaming SIMD extensions and AMD&#174; family 10h technologies are used to optimize for speed. 
-Programmers can concentrate on task functionality because Framewave handles performance. 
-Many of the functions are threaded internally; the programmer has the flexibility of 
-controlling the number of threads and of turning off threading. 
-As architecture changes and new instructions are added, new code paths 
-to take advantage of extensions can be added to Framewave without 
+<Paragraph>Framewave functions are geared to yield maximum performance on the x86 and the AMD64 hardware architectures.
+Current implementations exploit multicore architecture and single instruction multiple data (SIMD) instructions.
+Specifically, streaming SIMD extensions and AMD&#174; family 10h technologies are used to optimize for speed.
+Programmers can concentrate on task functionality because Framewave handles performance.
+Many of the functions are threaded internally; the programmer has the flexibility of
+controlling the number of threads and of turning off threading.
+As architecture changes and new instructions are added, new code paths
+to take advantage of extensions can be added to Framewave without
 changing the programming interface and existing functionality.</Paragraph>
 
 <Heading2>
@@ -384,18 +439,18 @@ changing the programming interface and existing functionality.</Paragraph>
 </Heading2>
 
 <Paragraph>This documentation is intended for experienced software developers. To understand the functional
-descriptions, a developer must be reasonably proficient in the C programming language, and must have 
+descriptions, a developer must be reasonably proficient in the C programming language, and must have
 a working knowledge of application-specific terminology and techniques.</Paragraph>
 
-<Paragraph>The documentation is divided into sections for each library. Within the sections, <Bold>Basic Concepts</Bold> chapters provide overview information related to the library  
+<Paragraph>The documentation is divided into sections for each library. Within the sections, <Bold>Basic Concepts</Bold> chapters provide overview information related to the library
 and subsequent chapters provide detailed descriptions of the library functions.</Paragraph>
 
-<Paragraph>Each detailed description consists of a <Bold>Function Name</Bold> followed by a short description, a <Bold>Synopsis</Bold> of the function syntax, 
-a list of function <Bold>Parameters</Bold>, a detailed <Bold>Description</Bold> of the function, and a list of <Bold>Return Values.</Bold></Paragraph> 
+<Paragraph>Each detailed description consists of a <Bold>Function Name</Bold> followed by a short description, a <Bold>Synopsis</Bold> of the function syntax,
+a list of function <Bold>Parameters</Bold>, a detailed <Bold>Description</Bold> of the function, and a list of <Bold>Return Values.</Bold></Paragraph>
 
-<Paragraph>When a function is optimized for one or more technologies, a list of <Bold>Supported Technologies</Bold> is provided after the short description. 
-Most function groups are optimized for the same technologies, but the lists are function-specific; the use of a particular optimization in a single function 
-does not indicate that all the functions in the group are optimized for that technology. When no list of optimizations is present, a function has only reference code. 
+<Paragraph>When a function is optimized for one or more technologies, a list of <Bold>Supported Technologies</Bold> is provided after the short description.
+Most function groups are optimized for the same technologies, but the lists are function-specific; the use of a particular optimization in a single function
+does not indicate that all the functions in the group are optimized for that technology. When no list of optimizations is present, a function has only reference code.
 Absence of optimizations does not mean that a function runs more slowly -- use of a particular optimization may not increase the performance of the function.
 </Paragraph>
 
@@ -469,7 +524,7 @@ precisely reports the result of execution. The following return value definition
 <H1Link>aa_006_install</H1Link>
 </Heading1>
 
-<Paragraph>This section contains general information about installing and using Framewave. Please refer to the README 
+<Paragraph>This section contains general information about installing and using Framewave. Please refer to the README
 file in the installation package for the most recent information.</Paragraph>
 
 <Heading2>
@@ -479,7 +534,7 @@ file in the installation package for the most recent information.</Paragraph>
 
 <Paragraph>The include directory contains the following files.</Paragraph>
 
-<Paragraph><Bold>fwBase.h </Bold>contains definitions of data types, data structures, 
+<Paragraph><Bold>fwBase.h </Bold>contains definitions of data types, data structures,
 	       enumerations, and declarations for core functions.</Paragraph>
 
 <Paragraph><Bold>fwSignal.h </Bold>contains function declarations for signal processing.</Paragraph>
@@ -530,8 +585,8 @@ file in the installation package for the most recent information.</Paragraph>
 <Paragraph><Bold>Microsoft&#174; Windows&#174; Operating Systems</Bold></Paragraph>
 
 <ParagraphIndent>DLL Directories</ParagraphIndent>
-<ParagraphIndent>The fwImage/fwSignal/fwBase/fwJPEG/fwVideo.lib files contain the 
-import address table (IAT) for the corresponding functions. Rather than fetching the 
+<ParagraphIndent>The fwImage/fwSignal/fwBase/fwJPEG/fwVideo.lib files contain the
+import address table (IAT) for the corresponding functions. Rather than fetching the
 address of the function during run time, the .lib files are used to link against a DLL at compile time.</ParagraphIndent>
 
 <ParagraphIndent>The fwImage/fwSignal/fwBase/fwJPEG/fwVideo.dll files contain implemented functions.</ParagraphIndent>
@@ -563,17 +618,17 @@ address of the function during run time, the .lib files are used to link against
 
 <Paragraph><Bold>Microsoft&#174; Windows&#174; Operating Systems</Bold></Paragraph>
 <Paragraph>Make sure the DLL files are in the search PATH using one of the following methods.</Paragraph>
-<BulletedList>  
-<Bullet>Copy the DLL files to the same folder as the project executable.</Bullet> 
-<Bullet>Copy the DLL files to a folder that in the search path 
+<BulletedList>
+<Bullet>Copy the DLL files to the same folder as the project executable.</Bullet>
+<Bullet>Copy the DLL files to a folder that in the search path
 (for example, the Windows folder).</Bullet>
-<Bullet>Modify the PATH environment variable to include the location of the Framewave DLLs 
+<Bullet>Modify the PATH environment variable to include the location of the Framewave DLLs
 (<Bold>Control Panel&gt;System&gt;Advanced&gt;Environment Variables</Bold>).</Bullet>
 </BulletedList>
-<Paragraph>Add the Framewave folder to the include search path within Microsoft Visual Studio (<Bold>Project&gt;Properties&gt;Configuration Properties&gt;C/C++&gt;General&gt; 
+<Paragraph>Add the Framewave folder to the include search path within Microsoft Visual Studio (<Bold>Project&gt;Properties&gt;Configuration Properties&gt;C/C++&gt;General&gt;
 Additional Include Directories</Bold>).</Paragraph>
 
-<Paragraph>Add the Framewave lib folder to the libraries search path within Visual Studio (<Bold>Project&gt;properties&gt;Configuration Properties&gt;Linker&gt;General&gt; 
+<Paragraph>Add the Framewave lib folder to the libraries search path within Visual Studio (<Bold>Project&gt;properties&gt;Configuration Properties&gt;Linker&gt;General&gt;
 Additional Library Directories</Bold>).</Paragraph>
 
 <Paragraph><Bold>Linux&#174; Operating Systems</Bold></Paragraph>
@@ -588,7 +643,7 @@ Additional Library Directories</Bold>).</Paragraph>
      ln -sf ./libfwJPEG.so.1.0.0 libfwJPEG.so
      ln -sf ./libfwSignal.so.1.0.0 libfwSignal.so
      ln -sf ./libfwVideo.so.1.0.0 libfwVideo.so</Pseudo>
-     
+
 <Paragraph>Create similar symbolic links with the .so.1 extension.</Paragraph>
 
 <Paragraph>To compile a cpp file that uses Framewave, for example test.cpp:</Paragraph>
@@ -597,15 +652,15 @@ Additional Library Directories</Bold>).</Paragraph>
 
 <Paragraph>All Framewave libraries have dependency on fwBase.</Paragraph>
 
-<ParagraphIndent>For example, to link with with the Image library,</ParagraphIndent> 
+<ParagraphIndent>For example, to link with with the Image library,</ParagraphIndent>
 <Pseudo>     g++ -m64 -LExampleDir/FW_1.0_Lin64/lib test.o -lfwImage -lfwBase</Pseudo>
 
-<Paragraph>It may be necessary to explicitly link in the stdc++, pthreads, 
-or math libraries if they are not automatically linked in.</Paragraph> 
+<Paragraph>It may be necessary to explicitly link in the stdc++, pthreads,
+or math libraries if they are not automatically linked in.</Paragraph>
 
-<Paragraph>Before running the application, make sure the ExampleDir/FW_1.0_Lin64/lib 
+<Paragraph>Before running the application, make sure the ExampleDir/FW_1.0_Lin64/lib
 is in the shared library search path for the environment.</Paragraph>
-   
+
 <Paragraph><Bold>Sun&#174; Solaris&#174; Operating Systems</Bold></Paragraph>
 
 <Paragraph>Assume this is a 64-bit installation and the installation directory is "ExampleDir".</Paragraph>
@@ -618,19 +673,19 @@ is in the shared library search path for the environment.</Paragraph>
      ln -sf ./libfwJPEG.so.1.0.0 libfwJPEG.so
      ln -sf ./libfwSignal.so.1.0.0 libfwSignal.so
      ln -sf ./libfwVideo.so.1.0.0 libfwVideo.so</Pseudo>
-     
+
 <Paragraph>Create similar symbolic links with the .so.1 extension.</Paragraph>
 
 <Paragraph>To compile a cpp file that uses Framewave, for example test.cpp:</Paragraph>
 
 <Pseudo>     CC -m64 -c -IExampleDir/FW_1.0_Sol64 test.cpp</Pseudo>
 
-<Paragraph>All Framewave libraries have dependency on fwBase.</Paragraph> 
+<Paragraph>All Framewave libraries have dependency on fwBase.</Paragraph>
 
-<ParagraphIndent>For example, to link with with the Image library,</ParagraphIndent> 
+<ParagraphIndent>For example, to link with with the Image library,</ParagraphIndent>
 <Pseudo>     CC -m64 -LExampleDir/FW_1.0_Sol64/lib test.o -lfwImage -lfwBase -lrt</Pseudo>
 
-<Paragraph>Before running the application, make sure the ExampleDir/FW_1.0_Sol64/lib 
+<Paragraph>Before running the application, make sure the ExampleDir/FW_1.0_Sol64/lib
 is in the shared library search path for the environment.</Paragraph>
 
 <Paragraph><Bold>Apple&#174; Mac OS&#174; Operating Systems</Bold></Paragraph>
@@ -645,22 +700,22 @@ is in the shared library search path for the environment.</Paragraph>
     ln -sf ./libfwJPEG-1.0.dylib libfwJPEG.dylib
     ln -sf ./libfwSignal-1.0.dylib libfwSignal.dylib
     ln -sf ./libfwVideo-1.0.dylib libfwVideo.dylib</Pseudo>
-     
+
 <Paragraph>Create similar symbolic links with the .1.dylib extension.</Paragraph>
 
 <Paragraph>To compile a cpp file that uses Framewave, for example test.cpp:</Paragraph>
 
 <Pseudo>     g++ -m64 -c -IExampleDir/FW_1.0_Mac64 test.cpp</Pseudo>
 
-<Paragraph>All Framewave libraries have dependency on fwBase.</Paragraph> 
+<Paragraph>All Framewave libraries have dependency on fwBase.</Paragraph>
 
-<ParagraphIndent>For example, to link with with the Image library,</ParagraphIndent> 
+<ParagraphIndent>For example, to link with with the Image library,</ParagraphIndent>
 <Pseudo>     g++ -m64 -LExampleDir/FW_1.0_Mac64/lib test.o -lfwImage -lfwBase</Pseudo>
 
-<Paragraph>It may be necessary to explicitly link in the stdc++, pthreads, 
-or math libraries if they are not automatically linked in.</Paragraph> 
+<Paragraph>It may be necessary to explicitly link in the stdc++, pthreads,
+or math libraries if they are not automatically linked in.</Paragraph>
 
-<Paragraph>Before running the application, make sure the ExampleDir/FW_1.0_Mac64/lib 
+<Paragraph>Before running the application, make sure the ExampleDir/FW_1.0_Mac64/lib
 is in the shared library search path for the environment.</Paragraph>
 
 <Heading2>
@@ -668,32 +723,32 @@ is in the shared library search path for the environment.</Paragraph>
 <H2Link>aa_install_004</H2Link>
 </Heading2>
 
-<Paragraph>This section describes how to resolve errors that occur while linking code to 
-the Framewave static library for Microsoft&#174; Windows&#174; operating systems. 
-This information does not apply to code that links to the dynamic DLL (shared) version of 
+<Paragraph>This section describes how to resolve errors that occur while linking code to
+the Framewave static library for Microsoft&#174; Windows&#174; operating systems.
+This information does not apply to code that links to the dynamic DLL (shared) version of
 the Framewave library for Microsoft Windows, or to versions of the Framewave library for other operating systems.</Paragraph>
 
-<Paragraph>Framewave static libraries for Microsoft Windows have a dependency on Microsoft Visual C++ 2005 
-C run-time libraries. The project (executable or DLL) also has a dependency on the C run-time library. 
-The linker automatically links to the run-time library used by the static library as well as to the 
-run-time library specified in the project settings. A version mismatch between the library in the static 
+<Paragraph>Framewave static libraries for Microsoft Windows have a dependency on Microsoft Visual C++ 2005
+C run-time libraries. The project (executable or DLL) also has a dependency on the C run-time library.
+The linker automatically links to the run-time library used by the static library as well as to the
+run-time library specified in the project settings. A version mismatch between the library in the static
 library and the library specified in the project can cause the linker to display error messages and terminate.</Paragraph>
 
 <Paragraph>To resolve this issue, use a static run-time library in the project.</Paragraph>
 
-<ParagraphIndent>When linking to a release version of the static Framewave library, use the /MT compiler switch 
-in the project settings. This links the project to the same static multithreaded version of the run-time 
+<ParagraphIndent>When linking to a release version of the static Framewave library, use the /MT compiler switch
+in the project settings. This links the project to the same static multithreaded version of the run-time
 Framewave library used by the static Framewave library.</ParagraphIndent>
 
-<ParagraphIndent>When linking to a debug version of the static Framewave library (common in debug configurations), 
-use the /MTd compiler switch in the project settings.  This links the project to the static multithreaded 
+<ParagraphIndent>When linking to a debug version of the static Framewave library (common in debug configurations),
+use the /MTd compiler switch in the project settings.  This links the project to the static multithreaded
 debug version of the run-time library.</ParagraphIndent>
 
-<Paragraph>Most code generated by the Visual C++ compiler has some dependency on the C runtime libraries. 
-Microsoft provides several different flavors of the run-time libraries (static vs. dynamic (DLL), debug vs. release), 
-and functions are implemented differently in each flavor. These differences can cause linker errors if a project is 
-linked to the wrong library flavor. The runtime library flavor is normally specified by a compiler switch 
-(/MT, /MTd, /MD, /MDd). Mixing different library types in the same module (executable or DLL) can also lead to various 
+<Paragraph>Most code generated by the Visual C++ compiler has some dependency on the C runtime libraries.
+Microsoft provides several different flavors of the run-time libraries (static vs. dynamic (DLL), debug vs. release),
+and functions are implemented differently in each flavor. These differences can cause linker errors if a project is
+linked to the wrong library flavor. The runtime library flavor is normally specified by a compiler switch
+(/MT, /MTd, /MD, /MDd). Mixing different library types in the same module (executable or DLL) can also lead to various
 linker or run-time issues, and is not recommended.</Paragraph>
 
 <Paragraph>For more information see: </Paragraph>
