@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2006-2008 Advanced Micro Devices, Inc. All Rights Reserved.
+Copyright (c) 2006-2009 Advanced Micro Devices, Inc. All Rights Reserved.
 This software is subject to the Apache v2.0 License.
 */
 
@@ -99,6 +99,20 @@ struct fe2St : public feBaseSt
 
 };
 
+
+template< typename TS1,  CH cs1  >  
+struct fe1St_96 : public fe1St<TS1, cs1>
+{   
+    typedef TS1  TS1_;      
+    const static CH CS1_      = cs1;
+
+    const static U32 nPIX_SSE = PIX_C3_96( TS1 ); 
+
+    class SRC1:  public RegDesc< TS1_,  CS1_,  nPIX_SSE > {};         
+};
+
+
+
 namespace PREFIX_OPT(OPT_PREFIX, FE_PRIVATE)
 {
    template< class FE >                                             // Common data / initialization routines
@@ -315,6 +329,7 @@ namespace PREFIX_OPT(OPT_PREFIX, FE_PRIVATE)
          for(U32 i=0; i<(this->threads); ++i)
          {
             td[i].pThis   = this; 
+            td[i].fe      = this->fe;
             td[i].s1      = FW_REF::Offset(s1, (T_OFFSET)i*(this->s1Step)*(T_OFFSET)heightTh);
             td[i].size    = heightTh;
             td[i].widthTh = this->width - px_nRef;
@@ -479,6 +494,7 @@ namespace PREFIX_OPT(OPT_PREFIX, FE_PRIVATE)
          for(U32 i=0; i<(this->threads); ++i)
          {
             td[i].pThis   = this;
+            td[i].fe      = this->fe;
             td[i].s1      = FW_REF::Offset(s1, (T_OFFSET)i*(this->s1Step)*(T_OFFSET)heightTh);
             td[i].s2      = FW_REF::Offset(s2, (T_OFFSET)i*(this->s2Step)*(T_OFFSET)heightTh);
             td[i].size    = heightTh;
