@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2006-2008 Advanced Micro Devices, Inc. All Rights Reserved.
+Copyright (c) 2006-2009 Advanced Micro Devices, Inc. All Rights Reserved.
 This software is subject to the Apache v2.0 License.
 */
 
@@ -19,7 +19,7 @@ namespace{
 		
 		// Determine how many bytes to pad at the end of each line
 		int pad = *pStepBytes%4;
-		if(pad > 0) pad = pad-4;
+		if(pad > 0) pad = 4-pad;
 
 		// Calculate size, and allocate!
 		*pStepBytes += pad;
